==> nextcloud-app-bookmarks-1%3A15.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/id.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Markah",
    "No file provided for import" : "Berkas untuk impor tidak tersedia",
    "Bookmarks shared by %s" : "Markah dibagikan oleh %s",
    "Select bookmark" : "Pilih markah",
    "Details" : "Detil",
    "Rename" : "Ubah nama",
    "Copy link" : "Salin tautan",
    "Move" : "Pindah",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
    "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
    "Open all selected" : "Buka semua pilihan",
    "Move selection" : "Pindah pilihan",
    "Delete selection" : "Hapus pilihan",
    "Select all" : "Pilih semua",
    "Cancel selection" : "Batalkan pilihan",
    "RSS feed copied" : "Umpan RSS tersalin",
    "Go back" : "Kembali",
    "Select one or more tags" : "Pilih satu atau lebih tag",
    "New" : "Baru",
    "New bookmark" : "Markah baru",
    "New folder" : "Folder baru",
    "Search" : "Cari",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "_%n folder_::_%n folders_" : ["%n folder"],
    "Add a bookmark" : "Tambahkan markah",
    "Select folder" : "Pilih folder",
    "Shared by {user}" : "Dibagikan oleh {user}",
    "Rename folder" : "Ubah nama folder",
    "Cancel" : "Membatalkan",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
    "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n markah"],
    "Recent" : "Terbaru",
    "Shared with you" : "Shared with you",
    "Files" : "Berkas",
    "Delete" : "Hapus",
    "Untagged" : "Belum ada tag",
    "No bookmarks here" : "Tidak ada markah di sini",
    "Client apps" : "Aplikasi klien",
    "Need help?" : "Butuh bantuan?",
    "Title" : "Judul",
    "Link" : "Tautan",
    "Root folder" : "Folder akar",
    "Tags" : "Tag",
    "Notes" : "Catatan",
    "Link copied" : "Link tersalin",
    "Owner" : "Owner",
    "Sharing" : "Berbagi",
    "Select a user or group" : "Pilih pengguna atau grup",
    "Share link" : "Bagikan tautan",
    "Copy RSS feed" : "Salin umpan RSS",
    "Delete link" : "Hapus tautan",
    "Create public link" : "Buat tautan publik",
    "Allow editing" : "Izinkan penyuntingan",
    "Allow resharing" : "Izinkan pembagian ulang",
    "Failed to save settings" : "Gagal simpan setelan",
    "Privacy" : "Privasi",
    "Performance" : "Performa",
    "Previews" : "Pratinjau",
    "Enter bookmark title" : "Tulis judul markah",
    "Enter bookmark URL" : "Tulis URL markah",
    "Folder" : "Folder",
    "Root Folder" : "Folder Akar",
    "Save" : "Simpan",
    "Failed to find existing bookmark" : "Gagal mencari markah eksis",
    "Failed to create bookmark" : "Gagal membuat markah",
    "Failed to save bookmark" : "Gagal menyimpan markah",
    "Failed to move bookmark" : "Gagal memindahkan markah",
    "Failed to delete bookmark" : "Gagal menghapus markah",
    "Failed to load tags" : "Gagal memuat tag",
    "Failed to load folders" : "Gagal memuat folder",
    "Failed to delete folder" : "Gagal menghapus folder",
    "Failed to create folder" : "Gagal membuat folder",
    "Failed to fetch bookmarks." : "Gagal menampilkan markah",
    "Failed to load setting {key}" : "Gagal memuat setelan {key}",
    "Bookmarks feed" : "Umpan markah"
},
"nplurals=1; plural=0;");

==> nextcloud-app-bookmarks-1%3A16.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/id.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Markah",
    "No file provided for import" : "Berkas untuk impor tidak tersedia",
    "Bookmarks shared by %s" : "Markah dibagikan oleh %s",
    "Select bookmark" : "Pilih markah",
    "Details" : "Detil",
    "Rename" : "Ubah nama",
    "Copy link" : "Salin tautan",
    "Move" : "Pindah",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
    "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
    "Open all selected" : "Buka semua pilihan",
    "Move selection" : "Pindah pilihan",
    "Delete selection" : "Hapus pilihan",
    "Select all" : "Pilih semua",
    "Cancel selection" : "Batalkan pilihan",
    "RSS feed copied" : "Umpan RSS tersalin",
    "Go back" : "Kembali",
    "Select one or more tags" : "Pilih satu atau lebih tag",
    "New" : "Baru",
    "New bookmark" : "Markah baru",
    "New folder" : "Folder baru",
    "Search" : "Cari",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "_%n folder_::_%n folders_" : ["%n folder"],
    "Add a bookmark" : "Tambahkan markah",
    "Select folder" : "Pilih folder",
    "Shared by {user}" : "Dibagikan oleh {user}",
    "Rename folder" : "Ubah nama folder",
    "Cancel" : "Membatalkan",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
    "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n markah"],
    "Recent" : "Terbaru",
    "Shared with you" : "Shared with you",
    "Files" : "Berkas",
    "Delete" : "Hapus",
    "Untagged" : "Belum ada tag",
    "No bookmarks here" : "Tidak ada markah di sini",
    "Client apps" : "Aplikasi klien",
    "Need help?" : "Butuh bantuan?",
    "Created on {date}" : "Terbuat pada {date}",
    "Title" : "Judul",
    "Link" : "Tautan",
    "Root folder" : "Folder akar",
    "Tags" : "Tag",
    "Notes" : "Catatan",
    "Link copied" : "Link tersalin",
    "Owner" : "Owner",
    "Sharing" : "Berbagi",
    "Select a user or group" : "Pilih pengguna atau grup",
    "Share link" : "Bagikan tautan",
    "Copy RSS feed" : "Salin umpan RSS",
    "Delete link" : "Hapus tautan",
    "Create public link" : "Buat tautan publik",
    "Allow editing" : "Izinkan penyuntingan",
    "Allow resharing" : "Izinkan pembagian ulang",
    "Failed to save settings" : "Gagal simpan setelan",
    "Privacy" : "Privasi",
    "Performance" : "Performa",
    "Previews" : "Pratinjau",
    "Enter bookmark title" : "Tulis judul markah",
    "Enter bookmark URL" : "Tulis URL markah",
    "Folder" : "Folder",
    "Root Folder" : "Folder Akar",
    "Save" : "Simpan",
    "Failed to find existing bookmark" : "Gagal mencari markah eksis",
    "Failed to create bookmark" : "Gagal membuat markah",
    "Failed to save bookmark" : "Gagal menyimpan markah",
    "Failed to move bookmark" : "Gagal memindahkan markah",
    "Failed to delete bookmark" : "Gagal menghapus markah",
    "Failed to load tags" : "Gagal memuat tag",
    "Failed to load folders" : "Gagal memuat folder",
    "Failed to delete folder" : "Gagal menghapus folder",
    "Failed to create folder" : "Gagal membuat folder",
    "Failed to move parts of selection" : "Gagal memindahkan sebagai pilihan",
    "Failed to delete parts of selection" : "Gagal menghapus sebagian pilihan",
    "Failed to fetch bookmarks." : "Gagal menampilkan markah",
    "Failed to load setting {key}" : "Gagal memuat setelan {key}",
    "Bookmarks feed" : "Umpan markah"
},
"nplurals=1; plural=0;");
